@@ -8,7 +8,7 @@ use warnings;
 use Config;
 use Exporter;
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-$VERSION     = "0.10";
+$VERSION     = "0.11";
 @ISA         = ("Exporter");
 @EXPORT_OK   = qw( plv2hash summary myconfig signature );
 %EXPORT_TAGS = (
@@ -39,7 +39,9 @@ my %BTD = map { $_ => 0 } qw(
     PERL_MEM_LOG_TIMESTAMP
     PERL_USE_DEVEL
     PERL_USE_SAFE_PUTENV
+    USE_ATTRIBUTES_FOR_PERLIO
     USE_FAST_STDIO
+    USE_PERL_ATOF
     USE_SITECUSTOMIZE
 
     DEBUG_LEAKING_SCALARS
@@ -393,10 +395,11 @@ The extracted information is stored in 5 entries in the C<build> hash:
 
 =item osname
 
-This is most likely the same as C$Config{osname}>, and was the name
+This is most likely the same as C<$Config{osname}>, and was the name
 known when perl was built. It might be different if perl was cross-compiled.
 
-The default for this field, if it cannot be extracted, is to copy C<$Config{osname}>.
+The default for this field, if it cannot be extracted, is to copy
+C<$Config{osname}>. The two may be differing in casing (OpenBSD vs openbsd).
 
 =item stamp
 
@@ -467,7 +470,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 H.Merijn Brand
+Copyright (C) 2009-2010 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
